from django.db import models
from .default import AnyFileField

__all__ = ('AnyFileField', 'AnyImageField')


class AnyImageField(models.ImageField):
    """
    The standard Django `~django.forms.widgets.ImageField` with a preview.
    """
    def formfield(self, **kwargs):
        from any_imagefield.forms.fields import ImagePreviewField
        from any_imagefield.forms.widgets import ImagePreviewWidget
        kwargs['widget'] = ImagePreviewWidget   # hard override for admin
        defaults = {'form_class': ImagePreviewField}
        defaults.update(kwargs)
        return super(AnyImageField, self).formfield(**defaults)



"""
Custom model fields to link to CMS content.
"""
from django.conf import settings


# Include the imagefield.
if 'filebrowser' in settings.INSTALLED_APPS:
    from .backends import filebrowser as active_backend
elif 'sorl.thumbnail' in settings.INSTALLED_APPS:
    from .backends import sorl as active_backend
elif 'any_imagefield' in settings.INSTALLED_APPS:
    # Can use template-based previews
    from .backends import preview as active_backend
else:
    # Can't use template based either, use Plain old Django fields
    from .backends import default as active_backend


# This is included for documentation, consistent south migrations and editor code completion:
class AnyFileField(active_backend.AnyFileField):
    """
    The file browse field based on django-filebrowser, or any other filebrowser.
    It's a drop-in replacement for the django :class:`~django.db.models.FileField`

    When *django-filebrowser* is not installed, it will display the
    standard :class:`~django.db.models.FileField`.
    """


class AnyImageField(active_backend.AnyImageField):
    """
    The image field based on django-filebrowser, SORL thumbnail or any other image library.
    It's a drop-in replacement for the django :class:`~django.db.models.ImageField`

    When *django-filebrowser* is not installed, it will display the
    standard :class:`~django.db.models.ImageField` with a preview attached to it.
    """


# Tell South how to create custom fields
try:
    from south.modelsinspector import add_introspection_rules
    add_introspection_rules([], [
        "^any_imagefield\.models\.fields\.AnyFileField",
        "^any_imagefield\.models\.fields\.AnyImageField",
        "^any_imagefield\.models\.fields\.backends\.([^.]+)\.AnyFileField",
        "^any_imagefield\.models\.fields\.backends\.([^.]+)\.AnyImageField",
    ])
except ImportError:
    pass



"""
Custom form fields for CMS items
"""
from django import forms
from .widgets import ImagePreviewWidget


class ImagePreviewField(forms.ImageField):
    """
    An `~django.forms.widgets.ImageField` subclass that also displays an inline preview of the image.
    """
    widget = ImagePreviewWidget



from __future__ import absolute_import
from filebrowser.fields import FileBrowseField


class AnyFileField(FileBrowseField):
    """
    The file browse field based on django-filebrowser.
    """
    def __init__(self, *args, **kwargs):
        defaults = {
            'max_length': 100,  # Same as django FileField
            'format': 'Document',
            'directory': kwargs.pop('upload_to', ''),
        }

        defaults.update(kwargs)
        super(AnyFileField, self).__init__(*args, **defaults)


class AnyImageField(FileBrowseField):
    """
    The image browse field based on django-filebrowser.
    """
    def __init__(self, *args, **kwargs):
        defaults = {
            'max_length': 100,  # Same as django ImageField
            'format': 'Image',
            'directory': kwargs.pop('upload_to', ''),
        }

        defaults.update(kwargs)
        super(AnyImageField, self).__init__(*args, **defaults)



from django.db import models


class AnyFileField(models.FileField):
    """
    The standard Django `~django.forms.FileField` with a `~django.forms.ClearableFileInput` widget.
    """
    pass


class AnyImageField(models.ImageField):
    """
    The standard Django `~django.forms.ImageField` with a `~django.forms.ClearableFileInput` widget.
    """
    pass



from __future__ import absolute_import
from django.db import models
from django.utils.safestring import mark_safe
from sorl.thumbnail.admin.current import AdminImageWidget
from .default import AnyFileField  # can export as-is.

__all__ = ('AnyFileField', 'AnyImageField')


class FixedSorlAdminImageWidget(AdminImageWidget):
    # Fix the layout in the SORL AdminImageWidget
    template_with_initial = u'%(clear_template)s%(input_text)s: %(input)s'
    template_with_clear = u'<span class="clearable-file-input">%(clear)s <label style="width: auto;" for="%(clear_checkbox_id)s">%(clear_checkbox_label)s</label></span><br />'

    def render(self, name, value, attrs=None):
        # Make sure the help text is displayed below the widget.
        orig_output = super(FixedSorlAdminImageWidget, self).render(name, value, attrs)
        return mark_safe(
            orig_output \
            + u'<div style="clear: both;"></div>'
        )


class AnyImageField(models.ImageField):
    """
    The standard Django `~django.forms.widgets.ImageField` with a SORL thumbnail preview.
    """
    def formfield(self, **kwargs):
        kwargs['widget'] = FixedSorlAdminImageWidget   # hard override for admin
        return super(AnyImageField, self).formfield(**kwargs)



import mimetypes
from django.contrib.admin.widgets import AdminFileWidget
from django.template.loader import render_to_string


class ImagePreviewWidget(AdminFileWidget):
    """
    An :class:`~django.forms.FileInput` widget that also displays a preview of the image.
    """
    template_with_initial = u'%(clear_template)s</p><p>%(input_text)s: %(input)s'

    def render(self, name, value, attrs=None):
        is_image = False
        if value:
            (mime_type, encoding) = mimetypes.guess_type(value.path)
            is_image = mime_type and mime_type.startswith('image/')

        # Render different field for replacing
        input_field = super(ImagePreviewWidget, self).render(name, value, attrs)
        if not value:
            return input_field
        else:
            return render_to_string("any_imagefield/imagepreviewwidget/update.html", {
                'value': value,
                'is_image': is_image,
                'input_field': input_field,
                'input_text': self.input_text,
            })



#!/usr/bin/env python
from setuptools import setup, find_packages
from os.path import dirname, join


setup(
    name='django-any-imagefield',
    version='0.8.0',
    license='Apache License, Version 2.0',

    requires=[
        'Django (>=1.3)',   # Using staticfiles
    ],
    extras_require = {
        'filebrowser': ['django-filebrowser'],
    },
    dependency_links = [
        'git+https://github.com/wardi/django-filebrowser-no-grappelli.git#egg=django-filebrowser',
    ],

    description='A switchable ImageField for third party Django applications',
    long_description=open(join(dirname(__file__), 'README.rst')).read(),

    author='Diederik van der Boor',
    author_email='opensource@edoburu.nl',

    url='https://github.com/edoburu/django-any-imagefield',
    download_url='https://github.com/edoburu/django-any-imagefield/zipball/master',

    packages=find_packages(exclude=('example*',)),
    include_package_data=True,

    zip_safe=False,
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ]
)
